import requests
import json

API_KEY = ''

class StringFunctions(object):       
    def after(source_string, regex_pattern):
        """Returns a string containing everything in SourceString after the first instance of RegExPattern."""

        # Create JSON Payload to send
        source_string = source_string.replace("\\","\\\\")
        regex_pattern = regex_pattern.replace("\\","\\\\")
        parametersValueList = [source_string, regex_pattern]
        parametersTypeList = ['System.String', 'System.String']         
        jsonInputList = [{"type": pt ,"value": pv} for pt, pv in zip(parametersTypeList, parametersValueList)]
        payload ={"parameters": jsonInputList}

        # Send Request
        url = 'https://vfgwrongyh.execute-api.us-east-1.amazonaws.com/Alpha/clarity/after'
        headers = {'content-type': 'application/json', 'X-API-KEY': API_KEY}
        response = requests.post(url, data=json.dumps(payload), headers=headers)
        parsed_json = json.loads(response.text)
        return parsed_json['value']
    
    def before(source_string, regex_pattern):
        """Returns a string containing everything in SourceString before the first instance of RegExPattern."""

        # Create JSON Payload to send
        source_string = source_string.replace("\\","\\\\")
        regex_pattern = regex_pattern.replace("\\","\\\\")
        parametersValueList = [source_string, regex_pattern]
        parametersTypeList = ['System.String', 'System.String']      
        jsonInputList = [{"type": pt ,"value": pv} for pt, pv in zip(parametersTypeList, parametersValueList)]
        payload ={"parameters": jsonInputList}

        # Send Request
        url = 'https://vfgwrongyh.execute-api.us-east-1.amazonaws.com/Alpha/clarity/before'
        headers = {'content-type': 'application/json', 'X-API-KEY': API_KEY}
        response = requests.post(url, data=json.dumps(payload), headers=headers)
        parsed_json = json.loads(response.text)
        return parsed_json['value']

    def BestMatch(source_string, string_list):
        """Determines the best match betwring the supplied MatchString and a List(of String) based on the levenstein distance between the strings."""

        # Create JSON Payload to send
        source_string = source_string.replace("\\","\\\\")
        string_list = [s.replace('\\', '\\\\') for s in string_list]
        parametersValueList = [source_string, string_list]
        parametersTypeList = ['System.String', 'LS']  
        jsonInputList = [{"type": pt ,"value": pv} for pt, pv in zip(parametersTypeList, parametersValueList)]
        payload = {'parameters': jsonInputList}

        # Send Request
        url = 'https://vfgwrongyh.execute-api.us-east-1.amazonaws.com/Alpha/clarity/bestmatch'
        headers = {'content-type': 'application/json', 'X-API-KEY': API_KEY}
        response = requests.post(url, data=json.dumps(payload), headers=headers)
        parsed_json = json.loads(response.text)
        return parsed_json
        
    def clean_html(source_string):
        """Returns the HTMLData string with all HTML tags removed and escaped characters converted."""

        # Create JSON Payload to send
        source_string = source_string.replace("\\","\\\\")
        parametersValueList = [source_string]
        parametersTypeList = ['System.String']         
        jsonInputList = [{"type": pt ,"value": pv} for pt, pv in zip(parametersTypeList, parametersValueList)]
        payload ={"parameters": jsonInputList}

        # Send Request
        url = 'https://vfgwrongyh.execute-api.us-east-1.amazonaws.com/Alpha/clarity/cleanhtml'
        headers = {'content-type': 'application/json', 'X-API-KEY': API_KEY}
        response = requests.post(url, data=json.dumps(payload), headers=headers)
        parsed_json = json.loads(response.text)
        return parsed_json['value']
    
    def html_decode(source_string):
        """Returns the HTMLData string with all HTML tags removed and escaped characters converted."""

        # Create JSON Payload to send
        source_string = source_string.replace("\\","\\\\")
        parametersValueList = [source_string]
        parametersTypeList = ['System.String']         
        jsonInputList = [{"type": pt ,"value": pv} for pt, pv in zip(parametersTypeList, parametersValueList)]
        payload ={"parameters": jsonInputList}

        # Send Request
        url = 'https://vfgwrongyh.execute-api.us-east-1.amazonaws.com/Alpha/clarity/htmldecode'
        headers = {'content-type': 'application/json', 'X-API-KEY': API_KEY}
        response = requests.post(url, data=json.dumps(payload), headers=headers)
        parsed_json = json.loads(response.text)
        return parsed_json['value']
    
    def html_encode(source_string):
        """Returns a String with HTML special characters replaced with their encode characters."""

        # Create JSON Payload to send
        source_string = source_string.replace("\\","\\\\")
        parametersValueList = [source_string]
        parametersTypeList = ['System.String']         
        jsonInputList = [{"type": pt ,"value": pv} for pt, pv in zip(parametersTypeList, parametersValueList)]
        payload ={"parameters": jsonInputList}

        # Send Request
        url = 'https://vfgwrongyh.execute-api.us-east-1.amazonaws.com/Alpha/clarity/htmlencode'
        headers = {'content-type': 'application/json', 'X-API-KEY': API_KEY}
        response = requests.post(url, data=json.dumps(payload), headers=headers)
        parsed_json = json.loads(response.text)
        return parsed_json['value']
    
    def lev_distance(source_string, compare_string):
        """Returns the Levenstein distance between two strings.  If strings are over 1000 characters, only the first 1000 will be evaluated."""

        # Create JSON Payload to send
        source_string = source_string.replace("\\","\\\\")
        compare_string = compare_string.replace("\\","\\\\")
        parametersValueList = [source_string, compare_string]
        parametersTypeList = ['System.String','System.String']         
        jsonInputList = [{"type": pt ,"value": pv} for pt, pv in zip(parametersTypeList, parametersValueList)]
        payload ={"parameters": jsonInputList}

        # Send Request
        url = 'https://vfgwrongyh.execute-api.us-east-1.amazonaws.com/Alpha/clarity/levdistance'
        headers = {'content-type': 'application/json', 'X-API-KEY': API_KEY}
        response = requests.post(url, data=json.dumps(payload), headers=headers)
        parsed_json = json.loads(response.text)
        return parsed_json['value']

    def md5(source_string):
        """Returns an MD5 hash of the specified string."""

        # Create JSON Payload to send
        source_string = source_string.replace("\\","\\\\")
        parametersValueList = [source_string]
        parametersTypeList = ['System.String']         
        jsonInputList = [{"type": pt ,"value": pv} for pt, pv in zip(parametersTypeList, parametersValueList)]
        payload ={"parameters": jsonInputList}

        # Send Request
        url = 'https://vfgwrongyh.execute-api.us-east-1.amazonaws.com/Alpha/clarity/md5'
        headers = {'content-type': 'application/json', 'X-API-KEY': API_KEY}
        response = requests.post(url, data=json.dumps(payload), headers=headers)
        parsed_json = json.loads(response.text)
        return parsed_json['value']
    
    def regex_chunk(source_string, regex_string, case_sensitive=False, RemoveEmpty=False):
        """If RegExPattern contains a capture group the returned values will alternate between data between the pattern and the pattern."""

        # Create JSON Payload to send
        source_string = source_string.replace("\\","\\\\")
        regex_string = regex_string.replace("\\","\\\\")
        parametersValueList = [source_string, regex_string, case_sensitive, RemoveEmpty]
        parametersTypeList = ['System.String','System.String', 'System.Boolean', 'System.Boolean']         
        jsonInputList = [{"type": pt ,"value": pv} for pt, pv in zip(parametersTypeList, parametersValueList)]
        payload ={"parameters": jsonInputList}

        # Send Request
        url = 'https://vfgwrongyh.execute-api.us-east-1.amazonaws.com/Alpha/clarity/regexchunk'
        headers = {'content-type': 'application/json', 'X-API-KEY': API_KEY}
        response = requests.post(url, data=json.dumps(payload), headers=headers)
        parsed_json = json.loads(response.text)
        
        #Parse the values in the array
        output = []
        for val in parsed_json['output']:
            output.append(val['value'])
            
        return output
    
    def regex_count(source_string, regex_string, case_sensitive=False):
        """Returns an integer containing the number of times a RegEx pattern is found in the source."""

        # Create JSON Payload to send
        source_string = source_string.replace("\\","\\\\")
        regex_string = regex_string.replace("\\","\\\\")
        parametersValueList = [source_string, regex_string, case_sensitive]
        parametersTypeList = ['System.String','System.String', 'System.Boolean']         
        jsonInputList = [{"type": pt ,"value": pv} for pt, pv in zip(parametersTypeList, parametersValueList)]
        payload ={"parameters": jsonInputList}

        # Send Request
        url = 'https://vfgwrongyh.execute-api.us-east-1.amazonaws.com/Alpha/clarity/regexcount'
        headers = {'content-type': 'application/json', 'X-API-KEY': API_KEY}
        response = requests.post(url, data=json.dumps(payload), headers=headers)
        parsed_json = json.loads(response.text)
        return parsed_json['value']
    
    def regex_extract_each(source_string, regex_string, case_sensitive=False, reverse_search=False, return_nothing_on_pattern_fail=False):
        """Returns an array of strings extracted from SourceString using RegExPattern, one value for each capture group defined in the pattern"""
        
        # Create JSON Payload to send
        source_string = source_string.replace("\\","\\\\")
        regex_string = regex_string.replace("\\","\\\\")
        parametersValueList = [source_string, regex_string, case_sensitive, reverse_search,return_nothing_on_pattern_fail]
        parametersTypeList = ['System.String','System.String', 'System.Boolean', 'System.Boolean','System.Boolean']         
        jsonInputList = [{"type": pt ,"value": pv} for pt, pv in zip(parametersTypeList, parametersValueList)]
        payload ={"parameters": jsonInputList}

        # Send Request
        url = 'https://vfgwrongyh.execute-api.us-east-1.amazonaws.com/Alpha/clarity/regexextracteach'
        headers = {'content-type': 'application/json', 'X-API-KEY': API_KEY}
        response = requests.post(url, data=json.dumps(payload), headers=headers)
        parsed_json = json.loads(response.text)
        
        #Parse the values in the array
        output = []
        for val in parsed_json['output']:
            output.append(val['value'])
            
        return output
    
    def regex_extract(source_string, regex_string, outputstring="", case_sensitive=False, reverse_search=False, return_nothing_on_pattern_fail=False):
        """Returns a string extracted from SourceString using RegExPattern."""
        
        # Create JSON Payload to send
        source_string = source_string.replace("\\","\\\\")
        regex_string = regex_string.replace("\\","\\\\")
        outputstring = outputstring.replace("\\","\\\\")
        parametersValueList = [source_string, regex_string, outputstring, case_sensitive, reverse_search,return_nothing_on_pattern_fail]
        parametersTypeList = ['System.String','System.String','System.String','System.Boolean','System.Boolean','System.Boolean']      
        
        jsonInputList = [{"type": pt ,"value": pv} for pt, pv in zip(parametersTypeList, parametersValueList)]
        payload ={"parameters": jsonInputList}

        # Send Request
        url = 'https://vfgwrongyh.execute-api.us-east-1.amazonaws.com/Alpha/clarity/regexextract'
        headers = {'content-type': 'application/json', 'X-API-KEY': API_KEY}
        response = requests.post(url, data=json.dumps(payload), headers=headers)
        parsed_json = json.loads(response.text)
        return parsed_json['value']
    
    def regex_extract_all(source_string, regex_string, OutputString="", case_sensitive=False):
        """Returns an array of strings extracted from SourceString using RegExPattern"""
        
        # Create JSON Payload to send
        source_string = source_string.replace("\\","\\\\")
        regex_string = regex_string.replace("\\","\\\\")
        parametersValueList = [source_string, regex_string, OutputString, case_sensitive]
        parametersTypeList = ['System.String','System.String', 'System.String','System.Boolean']         
        jsonInputList = [{"type": pt ,"value": pv} for pt, pv in zip(parametersTypeList, parametersValueList)]
        payload ={"parameters": jsonInputList}

        # Send Request
        url = 'https://vfgwrongyh.execute-api.us-east-1.amazonaws.com/Alpha/clarity/regexextractall'
        headers = {'content-type': 'application/json', 'X-API-KEY': API_KEY}
        response = requests.post(url, data=json.dumps(payload), headers=headers)
        parsed_json = json.loads(response.text)
        
        #Parse the values in the array
        output = []
        for val in parsed_json['output']:
            output.append(val['value'])
            
        return output
    
    
    def regex_extract_int(source_string, regex_string, case_sensitive=False):
        """regexextractint"""
        
        # Create JSON Payload to send
        source_string = source_string.replace("\\","\\\\")
        regex_string = regex_string.replace("\\","\\\\")
        parametersValueList = [source_string, regex_string, case_sensitive]
        parametersTypeList = ['System.String','System.String', 'System.Boolean']         
        jsonInputList = [{"type": pt ,"value": pv} for pt, pv in zip(parametersTypeList, parametersValueList)]
        payload ={"parameters": jsonInputList}

        # Send Request
        url = 'https://vfgwrongyh.execute-api.us-east-1.amazonaws.com/Alpha/clarity/regexextractint'
        headers = {'content-type': 'application/json', 'X-API-KEY': API_KEY}
        response = requests.post(url, data=json.dumps(payload), headers=headers)
        parsed_json = json.loads(response.text)
        return parsed_json['value']
    
    def regex_is_match(source_string, regex_string, case_sensitive=False):
        """Returns a boolean indicating if RegExPattern is a match for SourceString."""
        
        # Create JSON Payload to send
        source_string = source_string.replace("\\","\\\\")
        regex_string = regex_string.replace("\\","\\\\")
        parametersValueList = [source_string, regex_string, case_sensitive]
        parametersTypeList = ['System.String','System.String', 'System.Boolean']         
        jsonInputList = [{"type": pt ,"value": pv} for pt, pv in zip(parametersTypeList, parametersValueList)]
        payload ={"parameters": jsonInputList}

        # Send Request
        url = 'https://vfgwrongyh.execute-api.us-east-1.amazonaws.com/Alpha/clarity/regexismatch'
        headers = {'content-type': 'application/json', 'X-API-KEY': API_KEY}
        response = requests.post(url, data=json.dumps(payload), headers=headers)
        parsed_json = json.loads(response.text)
        return parsed_json['value']
    
    def regex_replace(source_string, regex_string, replaceString, case_sensitive=False):
        """Returns SourceString after replacing any matches found with RegExPattern with ReplaceString."""
        
        # Create JSON Payload to send
        source_string = source_string.replace("\\","\\\\")
        regex_string = regex_string.replace("\\","\\\\")
        replaceString = replaceString.replace("\\","\\\\")
        parametersValueList = [source_string, regex_string, replaceString, case_sensitive]
        parametersTypeList = ['System.String','System.String','System.String', 'System.Boolean']         
        jsonInputList = [{"type": pt ,"value": pv} for pt, pv in zip(parametersTypeList, parametersValueList)]
        payload ={"parameters": jsonInputList}

        # Send Request
        url = 'https://vfgwrongyh.execute-api.us-east-1.amazonaws.com/Alpha/clarity/regexreplace'
        headers = {'content-type': 'application/json', 'X-API-KEY': API_KEY}
        response = requests.post(url, data=json.dumps(payload), headers=headers)
        parsed_json = json.loads(response.text)
        return parsed_json['value']
    
    def regex_escape(source_string):
        """Returns string with common regex chars escaped out."""
        
        # Create JSON Payload to send
        source_string = source_string.replace("\\","\\\\")
        parametersValueList = [source_string]
        parametersTypeList = ['System.String']         
        jsonInputList = [{"type": pt ,"value": pv} for pt, pv in zip(parametersTypeList, parametersValueList)]
        payload ={"parameters": jsonInputList}

        # Send Request
        url = 'https://vfgwrongyh.execute-api.us-east-1.amazonaws.com/Alpha/clarity/regexescape'
        headers = {'content-type': 'application/json', 'X-API-KEY': API_KEY}
        response = requests.post(url, data=json.dumps(payload), headers=headers)
        parsed_json = json.loads(response.text)
        return parsed_json['value']
    
    def remove_diacritics(source_string):
        """Removes characters with diacritics and replaces them with the closest ASCII character(s)"""
        
        # Create JSON Payload to send
        source_string = source_string.replace("\\","\\\\")
        parametersValueList = [source_string]
        parametersTypeList = ['System.String']         
        jsonInputList = [{"type": pt ,"value": pv} for pt, pv in zip(parametersTypeList, parametersValueList)]
        payload ={"parameters": jsonInputList}

        # Send Request
        url = 'https://vfgwrongyh.execute-api.us-east-1.amazonaws.com/Alpha/clarity/removediacritics'
        headers = {'content-type': 'application/json', 'X-API-KEY': API_KEY}
        response = requests.post(url, data=json.dumps(payload), headers=headers)
        parsed_json = json.loads(response.text)
        return parsed_json['value']
    
    def remove_duplicate_whitespacechars(source_string):
        """Removes blocks of whitespace from the text and replaces it with a single newline, tab, or space."""
        
        # Create JSON Payload to send
        source_string = source_string.replace("\\","\\\\")
        parametersValueList = [source_string]
        parametersTypeList = ['System.String']         
        jsonInputList = [{"type": pt ,"value": pv} for pt, pv in zip(parametersTypeList, parametersValueList)]
        payload ={"parameters": jsonInputList}

        # Send Request
        url = 'https://vfgwrongyh.execute-api.us-east-1.amazonaws.com/Alpha/clarity/removeduplicatewhitespacechars'
        headers = {'content-type': 'application/json', 'X-API-KEY': API_KEY}
        response = requests.post(url, data=json.dumps(payload), headers=headers)
        parsed_json = json.loads(response.text)
        return parsed_json['value']
    
    def remove_extra_whitespace(source_string):
        """Removes any whitespace chars in a string an returns a string that contains only single spaces in place of multi-spaces, newlines, tabs, etc."""
        
        # Create JSON Payload to send
        source_string = source_string.replace("\\","\\\\")
        parametersValueList = [source_string]
        parametersTypeList = ['System.String']         
        jsonInputList = [{"type": pt ,"value": pv} for pt, pv in zip(parametersTypeList, parametersValueList)]
        payload ={"parameters": jsonInputList}

        # Send Request
        url = 'https://vfgwrongyh.execute-api.us-east-1.amazonaws.com/Alpha/clarity/removeextrawhitespace'
        headers = {'content-type': 'application/json', 'X-API-KEY': API_KEY}
        response = requests.post(url, data=json.dumps(payload), headers=headers)
        parsed_json = json.loads(response.text)
        return parsed_json['value']
    
    def remove_invalid_filepathcharacters(source_string):
        """Returns a string with any invalid characters replaced with the Replacement string"""
       
        # Create JSON Payload to send
        source_string = source_string.replace("\\","\\\\")
        parametersValueList = [source_string]
        parametersTypeList = ['System.String']         
        jsonInputList = [{"type": pt ,"value": pv} for pt, pv in zip(parametersTypeList, parametersValueList)]
        payload ={"parameters": jsonInputList}

        # Send Request
        url = 'https://vfgwrongyh.execute-api.us-east-1.amazonaws.com/Alpha/clarity/removeinvalidfilepathcharacters'
        headers = {'content-type': 'application/json', 'X-API-KEY': API_KEY}
        response = requests.post(url, data=json.dumps(payload), headers=headers)
        parsed_json = json.loads(response.text)
        return parsed_json['value']
    
    def remove_whitespace(source_string):
        """Removes any whitespace chars in a string."""

        # Create JSON Payload to send
        source_string = source_string.replace("\\","\\\\")
        parametersValueList = [source_string]
        parametersTypeList = ['System.String']         
        jsonInputList = [{"type": pt ,"value": pv} for pt, pv in zip(parametersTypeList, parametersValueList)]
        payload ={"parameters": jsonInputList}

        # Send Request
        url = 'https://vfgwrongyh.execute-api.us-east-1.amazonaws.com/Alpha/clarity/removewhitespace'
        headers = {'content-type': 'application/json', 'X-API-KEY': API_KEY}
        response = requests.post(url, data=json.dumps(payload), headers=headers)
        parsed_json = json.loads(response.text)
        return parsed_json['value']
    
    
    def sha(source_string):
        """Returns an SHA512 hash of a string."""
        
        # Create JSON Payload to send
        source_string = source_string.replace("\\","\\\\")
        parametersValueList = [source_string]
        parametersTypeList = ['System.String']         
        jsonInputList = [{"type": pt ,"value": pv} for pt, pv in zip(parametersTypeList, parametersValueList)]
        payload ={"parameters": jsonInputList}

        # Send Request
        url = 'https://vfgwrongyh.execute-api.us-east-1.amazonaws.com/Alpha/clarity/sha'
        headers = {'content-type': 'application/json', 'X-API-KEY': API_KEY}
        response = requests.post(url, data=json.dumps(payload), headers=headers)
        parsed_json = json.loads(response.text)
        return parsed_json['value']

        

class Clean_Name(object):
    """docstring for Clean_Name"""
    def clean_name(source_string, exist_prefix=True, exist_suffix=True, exist_middle_name=True):
        # Create JSON Payload to send
        source_string = source_string.replace("\\","\\\\")
        parametersValueList = [source_string, exist_prefix, exist_suffix, exist_middle_name]
        parametersTypeList = ['System.String', 'System.Boolean', 'System.Boolean', 'System.Boolean']         
        jsonInputList = [{"type": pt ,"value": pv} for pt, pv in zip(parametersTypeList, parametersValueList)]
        payload = {"parameters": jsonInputList}
        
        # Send Request
        url = 'https://vfgwrongyh.execute-api.us-east-1.amazonaws.com/Alpha/clarity/cleanname'
        headers = {'content-type': 'application/json', 'X-API-KEY': API_KEY}
        response = requests.post(url, data=json.dumps(payload), headers=headers)
        parsed_json = json.loads(response.text)
        name_object = NameEntity(parsed_json)
        return name_object

class NameEntity(object):
    """docstring for ParsedName"""
    first_name = ''
    first_initial = ''
    last_name = ''
    last_initial = ''
    middle_name = ''
    middle_initial = ''
    name_string = ''
    prefix = ''
    suffix = ''

    def __init__(self, myjson):
        myjson['output']
        name_dict = {}
        for val in myjson['output']:
            for key,value in val.items():
                name_dict[key]=value

        self.first_name = name_dict['First']
        self.first_initial = name_dict['FirstInitial']
        self.last_name = name_dict['Last']
        self.last_initial = name_dict['LastInitial']
        self.middle_name = name_dict['Middle']
        self.middle_initial = name_dict['MiddleInitial']
        self.name_string = name_dict['NameString']
        self.prefix = name_dict['Prefix']
        self.suffix = name_dict['Suffix']
        
        


        
